@@ -1,25 +1,15 @@
-#
-# This file is part of Plack-Middleware-Pjax
-#
-# This software is copyright (c) 2011 by Matthew Phillips.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-#
 use strict;
 use warnings;
 
 package Plack::Middleware::Pjax;
-{
-  $Plack::Middleware::Pjax::VERSION = '1.113400';
-}
+$Plack::Middleware::Pjax::VERSION = '1.114400';
 # ABSTRACT: PJAX for your Plack
 use parent qw/Plack::Middleware/;
 
 
 use Plack::Util;
 use Plack::Request;
-use Marpa::HTML;
+use Marpa::R2::HTML;
 
 sub call {
     my ($self, $env) = @_;
@@ -37,17 +27,17 @@ sub call {
         Plack::Util::foreach($res->[2], sub { push @$body, $_[0]; });
         $body = join '', @$body;
 
-        my $stripped = Marpa::HTML::html( \$body,{
+        my $stripped = Marpa::R2::HTML::html( \$body,{
             q{*} => sub {
-                if (Marpa::HTML::attributes()->{$tag}) {
-                    push @{$Marpa::HTML::INSTANCE->{stripped}}, Marpa::HTML::contents();
+                if (Marpa::R2::HTML::attributes()->{$tag}) {
+                    push @{$Marpa::R2::HTML::INSTANCE->{stripped}}, Marpa::R2::HTML::contents();
                 }
             },
             q{title} => sub {
-                unshift @{$Marpa::HTML::INSTANCE->{stripped}}, Marpa::HTML::original();
+                unshift @{$Marpa::R2::HTML::INSTANCE->{stripped}}, Marpa::R2::HTML::original();
             },
             ':TOP' => sub {
-                $Marpa::HTML::INSTANCE->{stripped} || [];
+                $Marpa::R2::HTML::INSTANCE->{stripped} || [];
             }
         });
 
@@ -67,15 +57,18 @@ sub call {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Plack::Middleware::Pjax - PJAX for your Plack
 
 =head1 VERSION
 
-version 1.113400
+version 1.114400
 
 =head1 SYNOPSIS
 
@@ -89,7 +82,7 @@ version 1.113400
 
 Plack::Middleware::Pjax adds easy support for serving chromeless pages in combination with jquery-pjax. For more information on what pjax is, check the SEE ALSO links below.
 
-It does this by filtering the generated response through L<Marpa::HTML>. If the x-pjax http header is set, only the title and InnerHTML of the pjax-container are sent to the client.
+It does this by filtering the generated response through L<Marpa::R2::HTML>. If the x-pjax http header is set, only the title and InnerHTML of the pjax-container are sent to the client.
 
 Although you take a small processing hit adding an html parsing pass into the response cycle, using L<Plack::Middleware::Pjax> saves you from adding any view specific logic in your plack applications.
 
@@ -131,7 +124,7 @@ L<https://github.com/eval/rack-pjax>
 
 =item *
 
-L<Marpa::HTML>
+L<Marpa::R2::HTML>
 
 =item *
 
@@ -149,10 +142,9 @@ Matthew Phillips <mattp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Matthew Phillips.
+This software is copyright (c) 2015 by Matthew Phillips <mattp@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
